@@ -2,7 +2,7 @@ class FiberData:
     type = 'fiber'
 
     def __init__(
-        self, order_id, phone_number, iban, internet_speed, service_address, service_city,
+        self, order_id, phone_number, iban, service_address, service_city,
         service_zip, service_subdivision, shipment_address, shipment_city, shipment_zip,
         shipment_subdivision, previous_service, previous_provider, previous_internal_provider,
         previous_owner_vat, previous_owner_name, previous_owner_surname, notes,
@@ -33,7 +33,4 @@ class FiberData:
         self.vdf_fiber_coverage = vdf_fiber_coverage
         self.change_address = change_address
 
-        # ADSL the Tickets
-        self.internet_speed = internet_speed
-
         self.product = product
