@@ -10,8 +10,6 @@ class MobileDynamicFields(ProvisionDynamicFields):
             self._line(),
             self._icc_sc(),
             self._icc_donor(),
-            self._minutes(),
-            self._data(),
             self._service_type(),
             self._previous_provider(),
             self._previous_owner_vat(),
@@ -30,12 +28,6 @@ class MobileDynamicFields(ProvisionDynamicFields):
     def _icc_donor(self):
         return DynamicField("ICCdonant", self.service_data.icc)
 
-    def _minutes(self):
-        return DynamicField("minutsMobil", self.service_data.service_minutes)
-
-    def _data(self):
-        return DynamicField("dadesMobil", self.service_data.service_internet)
-
     def _service_type(self):
         if self.service_data.portability:
             return DynamicField("tipusServeiMobil", "portabilitat")
@@ -65,3 +57,9 @@ class MobileDynamicFields(ProvisionDynamicFields):
 
     def _subdivision(self):
         return DynamicField("provinciaMobil", self.customer_data.subdivision)
+
+    def _product(self):
+        return DynamicField(
+            name="productMobil",
+            value=self.service_data.product
+        )
