@@ -59,6 +59,10 @@ class InternetProcessTicket():
     def service_subdivision(self):
         return self.response.dynamic_field_get('provinciaServei').value
 
+    @property
+    def service_subdivision_code(self):
+        return self.response.dynamic_field_get('codiProvinciaServei').value
+
     @property
     def service_zip(self):
         return self.response.dynamic_field_get('CPservei').value
